==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/DeleteSourceLocationRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteSourceLocationRequest(sourceLocationName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DeleteSourceLocationRequest = {
    import DeleteSourceLocationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DeleteSourceLocationRequest
      .builder()
      .sourceLocationName(__string.unwrap(sourceLocationName): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.DeleteSourceLocationRequest.ReadOnly =
    zio.aws.mediatailor.model.DeleteSourceLocationRequest.wrap(buildAwsValue())
}
object DeleteSourceLocationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DeleteSourceLocationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DeleteSourceLocationRequest =
      zio.aws.mediatailor.model.DeleteSourceLocationRequest(sourceLocationName)
    def sourceLocationName: __string
    def getSourceLocationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(sourceLocationName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteSourceLocationRequest
  ) extends zio.aws.mediatailor.model.DeleteSourceLocationRequest.ReadOnly {
    override val sourceLocationName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.sourceLocationName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteSourceLocationRequest
  ): zio.aws.mediatailor.model.DeleteSourceLocationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.217.1-sources.jar: zio/aws/mediatailor/model/DeleteSourceLocationRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteSourceLocationRequest(sourceLocationName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DeleteSourceLocationRequest = {
    import DeleteSourceLocationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DeleteSourceLocationRequest
      .builder()
      .sourceLocationName(sourceLocationName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.DeleteSourceLocationRequest.ReadOnly =
    zio.aws.mediatailor.model.DeleteSourceLocationRequest.wrap(buildAwsValue())
}
object DeleteSourceLocationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DeleteSourceLocationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DeleteSourceLocationRequest =
      zio.aws.mediatailor.model.DeleteSourceLocationRequest(sourceLocationName)
    def sourceLocationName: __string
    def getSourceLocationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(sourceLocationName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteSourceLocationRequest
  ) extends zio.aws.mediatailor.model.DeleteSourceLocationRequest.ReadOnly {
    override val sourceLocationName: __string =
      impl.sourceLocationName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteSourceLocationRequest
  ): zio.aws.mediatailor.model.DeleteSourceLocationRequest.ReadOnly =
    new Wrapper(impl)
}
